==> v11.1.2.zip: brewman/overlord/src/app/recipe/recipe-routing.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule, inject } from '@angular/core';
import { ActivatedRouteSnapshot, RouterModule, RouterStateSnapshot, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { PeriodListResolver } from '../period/period-list-resolver.service';
import { ProductGroupListResolver } from '../product-group/product-group-list-resolver.service';

import { RecipeDetailComponent } from './recipe-detail/recipe-detail.component';
import { RecipeListComponent } from './recipe-list/recipe-list.component';
import { RecipeListResolver } from './recipe-list-resolver.service';
import { RecipeResolver } from './recipe-resolver.service';

const recipeRoutes: Routes = [
  {
    path: '',
    component: RecipeListComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Recipes',
    },
    resolve: {
      list: (route: ActivatedRouteSnapshot) => inject(RecipeListResolver).resolve(route),
      productGroups: () => inject(ProductGroupListResolver).resolve(),
      periods: () => inject(PeriodListResolver).resolve(),
    },
    runGuardsAndResolvers: 'paramsOrQueryParamsChange',
  },
  {
    path: 'new',
    component: RecipeDetailComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Recipes',
    },
    resolve: {
      item: (route: ActivatedRouteSnapshot) => inject(RecipeResolver).resolve(route),
      periods: () => inject(PeriodListResolver).resolve(),
    },
  },
  {
    path: ':id',
    component: RecipeDetailComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Recipes',
    },
    resolve: {
      item: (route: ActivatedRouteSnapshot) => inject(RecipeResolver).resolve(route),
      periods: () => inject(PeriodListResolver).resolve(),
    },
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(recipeRoutes)],
  exports: [RouterModule],
  providers: [RecipeListResolver, RecipeResolver],
})
export class RecipeRoutingModule {}

==> v11.6.0.zip: brewman/overlord/src/app/recipe/recipe-routing.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule, inject } from '@angular/core';
import { ActivatedRouteSnapshot, RouterModule, RouterStateSnapshot, Routes } from '@angular/router';

import { AuthGuard } from '../auth/auth-guard.service';
import { PeriodListResolver } from '../period/period-list-resolver.service';
import { ProductGroupListResolver } from '../product-group/product-group-list-resolver.service';

import { RecipeDetailComponent } from './recipe-detail/recipe-detail.component';
import { RecipeListComponent } from './recipe-list/recipe-list.component';
import { RecipeListResolver } from './recipe-list-resolver.service';
import { RecipeResolver } from './recipe-resolver.service';

const recipeRoutes: Routes = [
  {
    path: '',
    component: RecipeListComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Recipes',
    },
    resolve: {
      list: (route: ActivatedRouteSnapshot) => inject(RecipeListResolver).resolve(route),
      productGroups: () => inject(ProductGroupListResolver).resolve(),
      periods: () => inject(PeriodListResolver).resolve(),
    },
    runGuardsAndResolvers: 'paramsOrQueryParamsChange',
  },
  {
    path: 'new',
    component: RecipeDetailComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Recipes',
    },
    resolve: {
      item: (route: ActivatedRouteSnapshot) => inject(RecipeResolver).resolve(route),
      periods: () => inject(PeriodListResolver).resolve(),
    },
  },
  {
    path: ':id',
    component: RecipeDetailComponent,
    canActivate: [
      (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) => inject(AuthGuard).canActivate(route, state),
    ],
    data: {
      permission: 'Recipes',
    },
    resolve: {
      item: (route: ActivatedRouteSnapshot) => inject(RecipeResolver).resolve(route),
      periods: () => inject(PeriodListResolver).resolve(),
    },
  },
];

@NgModule({
  imports: [CommonModule, RouterModule.forChild(recipeRoutes)],
  exports: [RouterModule],
  providers: [RecipeListResolver, RecipeResolver],
})
export class RecipeRoutingModule {}
